@@ -37,7 +37,7 @@ package Time::OlsonTZ::Data;
 use warnings;
 use strict;
 
-our $VERSION = "0.202102";
+our $VERSION = "0.202301";
 
 use parent "Exporter";
 our @EXPORT_OK = qw(
@@ -77,7 +77,7 @@ retain this format in the future.
 
 =cut
 
-use constant olson_version => "2021b";
+use constant olson_version => "2023a";
 
 =item olson_code_version
 
@@ -89,7 +89,7 @@ piece of information.
 
 =cut
 
-use constant olson_code_version => "2021b";
+use constant olson_code_version => "2023a";
 
 =item olson_data_version
 
@@ -101,7 +101,7 @@ piece of information.
 
 =cut
 
-use constant olson_data_version => "2021b";
+use constant olson_data_version => "2023a";
 
 =back
 
@@ -135,14 +135,14 @@ my $cn = q(+{ map { ($_ => undef) } qw(
 	America/Bahia_Banderas America/Barbados America/Belem America/Belize
 	America/Boa_Vista America/Bogota America/Boise America/Cambridge_Bay
 	America/Campo_Grande America/Cancun America/Caracas America/Cayenne
-	America/Chicago America/Chihuahua America/Costa_Rica America/Cuiaba
-	America/Danmarkshavn America/Dawson America/Dawson_Creek America/Denver
-	America/Detroit America/Edmonton America/Eirunepe America/El_Salvador
-	America/Fort_Nelson America/Fortaleza America/Glace_Bay
-	America/Goose_Bay America/Grand_Turk America/Guatemala America/Guayaquil
-	America/Guyana America/Halifax America/Havana America/Hermosillo
-	America/Indiana/Indianapolis America/Indiana/Knox
-	America/Indiana/Marengo America/Indiana/Petersburg
+	America/Chicago America/Chihuahua America/Ciudad_Juarez
+	America/Costa_Rica America/Cuiaba America/Danmarkshavn America/Dawson
+	America/Dawson_Creek America/Denver America/Detroit America/Edmonton
+	America/Eirunepe America/El_Salvador America/Fort_Nelson
+	America/Fortaleza America/Glace_Bay America/Goose_Bay America/Grand_Turk
+	America/Guatemala America/Guayaquil America/Guyana America/Halifax
+	America/Havana America/Hermosillo America/Indiana/Indianapolis
+	America/Indiana/Knox America/Indiana/Marengo America/Indiana/Petersburg
 	America/Indiana/Tell_City America/Indiana/Vevay
 	America/Indiana/Vincennes America/Indiana/Winamac America/Inuvik
 	America/Iqaluit America/Jamaica America/Juneau
@@ -151,68 +151,61 @@ my $cn = q(+{ map { ($_ => undef) } qw(
 	America/Manaus America/Martinique America/Matamoros America/Mazatlan
 	America/Menominee America/Merida America/Metlakatla America/Mexico_City
 	America/Miquelon America/Moncton America/Monterrey America/Montevideo
-	America/New_York America/Nipigon America/Nome America/Noronha
+	America/New_York America/Nome America/Noronha
 	America/North_Dakota/Beulah America/North_Dakota/Center
 	America/North_Dakota/New_Salem America/Nuuk America/Ojinaga
-	America/Panama America/Pangnirtung America/Paramaribo America/Phoenix
-	America/Port-au-Prince America/Porto_Velho America/Puerto_Rico
-	America/Punta_Arenas America/Rainy_River America/Rankin_Inlet
-	America/Recife America/Regina America/Resolute America/Rio_Branco
-	America/Santarem America/Santiago America/Santo_Domingo
-	America/Sao_Paulo America/Scoresbysund America/Sitka America/St_Johns
-	America/Swift_Current America/Tegucigalpa America/Thule
-	America/Thunder_Bay America/Tijuana America/Toronto America/Vancouver
-	America/Whitehorse America/Winnipeg America/Yakutat America/Yellowknife
-	Antarctica/Casey Antarctica/Davis Antarctica/Macquarie Antarctica/Mawson
-	Antarctica/Palmer Antarctica/Rothera Antarctica/Troll Antarctica/Vostok
-	Asia/Almaty Asia/Amman Asia/Anadyr Asia/Aqtau Asia/Aqtobe Asia/Ashgabat
-	Asia/Atyrau Asia/Baghdad Asia/Baku Asia/Bangkok Asia/Barnaul Asia/Beirut
-	Asia/Bishkek Asia/Brunei Asia/Chita Asia/Choibalsan Asia/Colombo
-	Asia/Damascus Asia/Dhaka Asia/Dili Asia/Dubai Asia/Dushanbe
-	Asia/Famagusta Asia/Gaza Asia/Hebron Asia/Ho_Chi_Minh Asia/Hong_Kong
-	Asia/Hovd Asia/Irkutsk Asia/Jakarta Asia/Jayapura Asia/Jerusalem
-	Asia/Kabul Asia/Kamchatka Asia/Karachi Asia/Kathmandu Asia/Khandyga
-	Asia/Kolkata Asia/Krasnoyarsk Asia/Kuala_Lumpur Asia/Kuching Asia/Macau
-	Asia/Magadan Asia/Makassar Asia/Manila Asia/Nicosia Asia/Novokuznetsk
-	Asia/Novosibirsk Asia/Omsk Asia/Oral Asia/Pontianak Asia/Pyongyang
-	Asia/Qatar Asia/Qostanay Asia/Qyzylorda Asia/Riyadh Asia/Sakhalin
-	Asia/Samarkand Asia/Seoul Asia/Shanghai Asia/Singapore
-	Asia/Srednekolymsk Asia/Taipei Asia/Tashkent Asia/Tbilisi Asia/Tehran
-	Asia/Thimphu Asia/Tokyo Asia/Tomsk Asia/Ulaanbaatar Asia/Urumqi
-	Asia/Ust-Nera Asia/Vladivostok Asia/Yakutsk Asia/Yangon
+	America/Panama America/Paramaribo America/Phoenix America/Port-au-Prince
+	America/Porto_Velho America/Puerto_Rico America/Punta_Arenas
+	America/Rankin_Inlet America/Recife America/Regina America/Resolute
+	America/Rio_Branco America/Santarem America/Santiago
+	America/Santo_Domingo America/Sao_Paulo America/Scoresbysund
+	America/Sitka America/St_Johns America/Swift_Current America/Tegucigalpa
+	America/Thule America/Tijuana America/Toronto America/Vancouver
+	America/Whitehorse America/Winnipeg America/Yakutat Antarctica/Casey
+	Antarctica/Davis Antarctica/Macquarie Antarctica/Mawson
+	Antarctica/Palmer Antarctica/Rothera Antarctica/Troll Asia/Almaty
+	Asia/Amman Asia/Anadyr Asia/Aqtau Asia/Aqtobe Asia/Ashgabat Asia/Atyrau
+	Asia/Baghdad Asia/Baku Asia/Bangkok Asia/Barnaul Asia/Beirut
+	Asia/Bishkek Asia/Chita Asia/Choibalsan Asia/Colombo Asia/Damascus
+	Asia/Dhaka Asia/Dili Asia/Dubai Asia/Dushanbe Asia/Famagusta Asia/Gaza
+	Asia/Hebron Asia/Ho_Chi_Minh Asia/Hong_Kong Asia/Hovd Asia/Irkutsk
+	Asia/Jakarta Asia/Jayapura Asia/Jerusalem Asia/Kabul Asia/Kamchatka
+	Asia/Karachi Asia/Kathmandu Asia/Khandyga Asia/Kolkata Asia/Krasnoyarsk
+	Asia/Kuching Asia/Macau Asia/Magadan Asia/Makassar Asia/Manila
+	Asia/Nicosia Asia/Novokuznetsk Asia/Novosibirsk Asia/Omsk Asia/Oral
+	Asia/Pontianak Asia/Pyongyang Asia/Qatar Asia/Qostanay Asia/Qyzylorda
+	Asia/Riyadh Asia/Sakhalin Asia/Samarkand Asia/Seoul Asia/Shanghai
+	Asia/Singapore Asia/Srednekolymsk Asia/Taipei Asia/Tashkent Asia/Tbilisi
+	Asia/Tehran Asia/Thimphu Asia/Tokyo Asia/Tomsk Asia/Ulaanbaatar
+	Asia/Urumqi Asia/Ust-Nera Asia/Vladivostok Asia/Yakutsk Asia/Yangon
 	Asia/Yekaterinburg Asia/Yerevan Atlantic/Azores Atlantic/Bermuda
 	Atlantic/Canary Atlantic/Cape_Verde Atlantic/Faroe Atlantic/Madeira
-	Atlantic/Reykjavik Atlantic/South_Georgia Atlantic/Stanley
-	Australia/Adelaide Australia/Brisbane Australia/Broken_Hill
-	Australia/Darwin Australia/Eucla Australia/Hobart Australia/Lindeman
-	Australia/Lord_Howe Australia/Melbourne Australia/Perth Australia/Sydney
-	CET CST6CDT EET EST EST5EDT Etc/GMT Etc/GMT+1 Etc/GMT+10 Etc/GMT+11
-	Etc/GMT+12 Etc/GMT+2 Etc/GMT+3 Etc/GMT+4 Etc/GMT+5 Etc/GMT+6 Etc/GMT+7
-	Etc/GMT+8 Etc/GMT+9 Etc/GMT-1 Etc/GMT-10 Etc/GMT-11 Etc/GMT-12
-	Etc/GMT-13 Etc/GMT-14 Etc/GMT-2 Etc/GMT-3 Etc/GMT-4 Etc/GMT-5 Etc/GMT-6
-	Etc/GMT-7 Etc/GMT-8 Etc/GMT-9 Etc/UTC Europe/Amsterdam Europe/Andorra
-	Europe/Astrakhan Europe/Athens Europe/Belgrade Europe/Berlin
-	Europe/Brussels Europe/Bucharest Europe/Budapest Europe/Chisinau
-	Europe/Copenhagen Europe/Dublin Europe/Gibraltar Europe/Helsinki
-	Europe/Istanbul Europe/Kaliningrad Europe/Kiev Europe/Kirov
-	Europe/Lisbon Europe/London Europe/Luxembourg Europe/Madrid Europe/Malta
-	Europe/Minsk Europe/Monaco Europe/Moscow Europe/Oslo Europe/Paris
-	Europe/Prague Europe/Riga Europe/Rome Europe/Samara Europe/Saratov
-	Europe/Simferopol Europe/Sofia Europe/Stockholm Europe/Tallinn
-	Europe/Tirane Europe/Ulyanovsk Europe/Uzhgorod Europe/Vienna
-	Europe/Vilnius Europe/Volgograd Europe/Warsaw Europe/Zaporozhye
-	Europe/Zurich Factory HST Indian/Chagos Indian/Christmas Indian/Cocos
-	Indian/Kerguelen Indian/Mahe Indian/Maldives Indian/Mauritius
-	Indian/Reunion MET MST MST7MDT PST8PDT Pacific/Apia Pacific/Auckland
-	Pacific/Bougainville Pacific/Chatham Pacific/Chuuk Pacific/Easter
-	Pacific/Efate Pacific/Fakaofo Pacific/Fiji Pacific/Funafuti
+	Atlantic/South_Georgia Atlantic/Stanley Australia/Adelaide
+	Australia/Brisbane Australia/Broken_Hill Australia/Darwin
+	Australia/Eucla Australia/Hobart Australia/Lindeman Australia/Lord_Howe
+	Australia/Melbourne Australia/Perth Australia/Sydney CET CST6CDT EET EST
+	EST5EDT Etc/GMT Etc/GMT+1 Etc/GMT+10 Etc/GMT+11 Etc/GMT+12 Etc/GMT+2
+	Etc/GMT+3 Etc/GMT+4 Etc/GMT+5 Etc/GMT+6 Etc/GMT+7 Etc/GMT+8 Etc/GMT+9
+	Etc/GMT-1 Etc/GMT-10 Etc/GMT-11 Etc/GMT-12 Etc/GMT-13 Etc/GMT-14
+	Etc/GMT-2 Etc/GMT-3 Etc/GMT-4 Etc/GMT-5 Etc/GMT-6 Etc/GMT-7 Etc/GMT-8
+	Etc/GMT-9 Etc/UTC Europe/Andorra Europe/Astrakhan Europe/Athens
+	Europe/Belgrade Europe/Berlin Europe/Brussels Europe/Bucharest
+	Europe/Budapest Europe/Chisinau Europe/Dublin Europe/Gibraltar
+	Europe/Helsinki Europe/Istanbul Europe/Kaliningrad Europe/Kirov
+	Europe/Kyiv Europe/Lisbon Europe/London Europe/Madrid Europe/Malta
+	Europe/Minsk Europe/Moscow Europe/Paris Europe/Prague Europe/Riga
+	Europe/Rome Europe/Samara Europe/Saratov Europe/Simferopol Europe/Sofia
+	Europe/Tallinn Europe/Tirane Europe/Ulyanovsk Europe/Vienna
+	Europe/Vilnius Europe/Volgograd Europe/Warsaw Europe/Zurich Factory HST
+	Indian/Chagos Indian/Maldives Indian/Mauritius MET MST MST7MDT PST8PDT
+	Pacific/Apia Pacific/Auckland Pacific/Bougainville Pacific/Chatham
+	Pacific/Easter Pacific/Efate Pacific/Fakaofo Pacific/Fiji
 	Pacific/Galapagos Pacific/Gambier Pacific/Guadalcanal Pacific/Guam
 	Pacific/Honolulu Pacific/Kanton Pacific/Kiritimati Pacific/Kosrae
-	Pacific/Kwajalein Pacific/Majuro Pacific/Marquesas Pacific/Nauru
-	Pacific/Niue Pacific/Norfolk Pacific/Noumea Pacific/Pago_Pago
-	Pacific/Palau Pacific/Pitcairn Pacific/Pohnpei Pacific/Port_Moresby
-	Pacific/Rarotonga Pacific/Tahiti Pacific/Tarawa Pacific/Tongatapu
-	Pacific/Wake Pacific/Wallis WET
+	Pacific/Kwajalein Pacific/Marquesas Pacific/Nauru Pacific/Niue
+	Pacific/Norfolk Pacific/Noumea Pacific/Pago_Pago Pacific/Palau
+	Pacific/Pitcairn Pacific/Port_Moresby Pacific/Rarotonga Pacific/Tahiti
+	Pacific/Tarawa Pacific/Tongatapu WET
 ) });
 sub olson_canonical_names() {
 	$cn = eval($cn) || die $@ if ref($cn) eq "";
@@ -330,8 +323,11 @@ my $li = q(+{
 	"America/Montreal" => "America/Toronto",
 	"America/Montserrat" => "America/Puerto_Rico",
 	"America/Nassau" => "America/Toronto",
+	"America/Nipigon" => "America/Toronto",
+	"America/Pangnirtung" => "America/Iqaluit",
 	"America/Port_of_Spain" => "America/Puerto_Rico",
 	"America/Porto_Acre" => "America/Rio_Branco",
+	"America/Rainy_River" => "America/Winnipeg",
 	"America/Rosario" => "America/Argentina/Cordoba",
 	"America/Santa_Isabel" => "America/Tijuana",
 	"America/Shiprock" => "America/Denver",
@@ -340,16 +336,20 @@ my $li = q(+{
 	"America/St_Lucia" => "America/Puerto_Rico",
 	"America/St_Thomas" => "America/Puerto_Rico",
 	"America/St_Vincent" => "America/Puerto_Rico",
+	"America/Thunder_Bay" => "America/Toronto",
 	"America/Tortola" => "America/Puerto_Rico",
 	"America/Virgin" => "America/Puerto_Rico",
+	"America/Yellowknife" => "America/Edmonton",
 	"Antarctica/DumontDUrville" => "Pacific/Port_Moresby",
 	"Antarctica/McMurdo" => "Pacific/Auckland",
 	"Antarctica/South_Pole" => "Pacific/Auckland",
 	"Antarctica/Syowa" => "Asia/Riyadh",
-	"Arctic/Longyearbyen" => "Europe/Oslo",
+	"Antarctica/Vostok" => "Asia/Urumqi",
+	"Arctic/Longyearbyen" => "Europe/Berlin",
 	"Asia/Aden" => "Asia/Riyadh",
 	"Asia/Ashkhabad" => "Asia/Ashgabat",
 	"Asia/Bahrain" => "Asia/Qatar",
+	"Asia/Brunei" => "Asia/Kuching",
 	"Asia/Calcutta" => "Asia/Kolkata",
 	"Asia/Chongqing" => "Asia/Shanghai",
 	"Asia/Chungking" => "Asia/Shanghai",
@@ -358,6 +358,7 @@ my $li = q(+{
 	"Asia/Istanbul" => "Europe/Istanbul",
 	"Asia/Kashgar" => "Asia/Urumqi",
 	"Asia/Katmandu" => "Asia/Kathmandu",
+	"Asia/Kuala_Lumpur" => "Asia/Singapore",
 	"Asia/Kuwait" => "Asia/Riyadh",
 	"Asia/Macao" => "Asia/Macau",
 	"Asia/Muscat" => "Asia/Dubai",
@@ -371,6 +372,7 @@ my $li = q(+{
 	"Asia/Vientiane" => "Asia/Bangkok",
 	"Atlantic/Faeroe" => "Atlantic/Faroe",
 	"Atlantic/Jan_Mayen" => "Europe/Berlin",
+	"Atlantic/Reykjavik" => "Africa/Abidjan",
 	"Atlantic/St_Helena" => "Africa/Abidjan",
 	"Australia/ACT" => "Australia/Sydney",
 	"Australia/Canberra" => "Australia/Sydney",
@@ -408,23 +410,32 @@ my $li = q(+{
 	"Etc/UCT" => "Etc/UTC",
 	"Etc/Universal" => "Etc/UTC",
 	"Etc/Zulu" => "Etc/UTC",
+	"Europe/Amsterdam" => "Europe/Brussels",
 	"Europe/Belfast" => "Europe/London",
 	"Europe/Bratislava" => "Europe/Prague",
 	"Europe/Busingen" => "Europe/Zurich",
+	"Europe/Copenhagen" => "Europe/Berlin",
 	"Europe/Guernsey" => "Europe/London",
 	"Europe/Isle_of_Man" => "Europe/London",
 	"Europe/Jersey" => "Europe/London",
+	"Europe/Kiev" => "Europe/Kyiv",
 	"Europe/Ljubljana" => "Europe/Belgrade",
+	"Europe/Luxembourg" => "Europe/Brussels",
 	"Europe/Mariehamn" => "Europe/Helsinki",
+	"Europe/Monaco" => "Europe/Paris",
 	"Europe/Nicosia" => "Asia/Nicosia",
+	"Europe/Oslo" => "Europe/Berlin",
 	"Europe/Podgorica" => "Europe/Belgrade",
 	"Europe/San_Marino" => "Europe/Rome",
 	"Europe/Sarajevo" => "Europe/Belgrade",
 	"Europe/Skopje" => "Europe/Belgrade",
+	"Europe/Stockholm" => "Europe/Berlin",
 	"Europe/Tiraspol" => "Europe/Chisinau",
+	"Europe/Uzhgorod" => "Europe/Kyiv",
 	"Europe/Vaduz" => "Europe/Zurich",
 	"Europe/Vatican" => "Europe/Rome",
 	"Europe/Zagreb" => "Europe/Belgrade",
+	"Europe/Zaporozhye" => "Europe/Kyiv",
 	GB => "Europe/London",
 	"GB-Eire" => "Europe/London",
 	GMT => "Etc/GMT",
@@ -433,10 +444,15 @@ my $li = q(+{
 	GMT0 => "Etc/GMT",
 	Greenwich => "Etc/GMT",
 	Hongkong => "Asia/Hong_Kong",
-	Iceland => "Atlantic/Reykjavik",
+	Iceland => "Africa/Abidjan",
 	"Indian/Antananarivo" => "Africa/Nairobi",
+	"Indian/Christmas" => "Asia/Bangkok",
+	"Indian/Cocos" => "Asia/Yangon",
 	"Indian/Comoro" => "Africa/Nairobi",
+	"Indian/Kerguelen" => "Indian/Maldives",
+	"Indian/Mahe" => "Asia/Dubai",
 	"Indian/Mayotte" => "Africa/Nairobi",
+	"Indian/Reunion" => "Asia/Dubai",
 	Iran => "Asia/Tehran",
 	Israel => "Asia/Jerusalem",
 	Jamaica => "America/Jamaica",
@@ -450,14 +466,20 @@ my $li = q(+{
 	"NZ-CHAT" => "Pacific/Chatham",
 	Navajo => "America/Denver",
 	PRC => "Asia/Shanghai",
+	"Pacific/Chuuk" => "Pacific/Port_Moresby",
 	"Pacific/Enderbury" => "Pacific/Kanton",
+	"Pacific/Funafuti" => "Pacific/Tarawa",
 	"Pacific/Johnston" => "Pacific/Honolulu",
+	"Pacific/Majuro" => "Pacific/Tarawa",
 	"Pacific/Midway" => "Pacific/Pago_Pago",
-	"Pacific/Ponape" => "Pacific/Pohnpei",
+	"Pacific/Pohnpei" => "Pacific/Guadalcanal",
+	"Pacific/Ponape" => "Pacific/Guadalcanal",
 	"Pacific/Saipan" => "Pacific/Guam",
 	"Pacific/Samoa" => "Pacific/Pago_Pago",
-	"Pacific/Truk" => "Pacific/Chuuk",
-	"Pacific/Yap" => "Pacific/Chuuk",
+	"Pacific/Truk" => "Pacific/Port_Moresby",
+	"Pacific/Wake" => "Pacific/Tarawa",
+	"Pacific/Wallis" => "Pacific/Tarawa",
+	"Pacific/Yap" => "Pacific/Port_Moresby",
 	Poland => "Europe/Warsaw",
 	Portugal => "Europe/Lisbon",
 	ROC => "Asia/Taipei",
@@ -653,7 +675,7 @@ developed by Andrew Main (Zefram) <zefram@fysh.org>.
 The Olson timezone database is is the public domain.
 
 The C<Time::OlsonTZ::Data> Perl module wrapper for the database is
-Copyright (C) 2010, 2011, 2012, 2013, 2014, 2017, 2018, 2019, 2020, 2021
+Copyright (C) 2010, 2011, 2012, 2013, 2014, 2017, 2018, 2019, 2020, 2021, 2022, 2023
 Andrew Main (Zefram) <zefram@fysh.org>.
 
 =head1 LICENSE
